@@ -28,8 +28,6 @@ import com.google.gson.stream.MalformedJsonException;
 import java.io.IOException;
 import java.io.StringReader;
 import java.io.StringWriter;
-import java.lang.reflect.Field;
-import java.lang.reflect.Type;
 import java.text.DateFormat;
 import java.util.ArrayList;
 import java.util.Collections;
@@ -49,13 +47,7 @@ public final class GsonTest {
   private static final Excluder CUSTOM_EXCLUDER =
       Excluder.DEFAULT.excludeFieldsWithoutExposeAnnotation().disableInnerClassSerialization();
 
-  private static final FieldNamingStrategy CUSTOM_FIELD_NAMING_STRATEGY =
-      new FieldNamingStrategy() {
-        @Override
-        public String translateName(Field f) {
-          return "foo";
-        }
-      };
+  private static final FieldNamingStrategy CUSTOM_FIELD_NAMING_STRATEGY = f -> "foo";
 
   private static final ToNumberStrategy CUSTOM_OBJECT_TO_NUMBER_STRATEGY = ToNumberPolicy.DOUBLE;
   private static final ToNumberStrategy CUSTOM_NUMBER_TO_NUMBER_STRATEGY =
@@ -72,7 +64,7 @@ public final class GsonTest {
         new Gson(
             CUSTOM_EXCLUDER,
             CUSTOM_FIELD_NAMING_STRATEGY,
-            new HashMap<Type, InstanceCreator<?>>(),
+            new HashMap<>(),
             true,
             false,
             true,
@@ -85,12 +77,12 @@ public final class GsonTest {
             null,
             DateFormat.DEFAULT,
             DateFormat.DEFAULT,
-            new ArrayList<TypeAdapterFactory>(),
-            new ArrayList<TypeAdapterFactory>(),
-            new ArrayList<TypeAdapterFactory>(),
+            new ArrayList<>(),
+            new ArrayList<>(),
+            new ArrayList<>(),
             CUSTOM_OBJECT_TO_NUMBER_STRATEGY,
             CUSTOM_NUMBER_TO_NUMBER_STRATEGY,
-            Collections.<ReflectionAccessFilter>emptyList());
+            Collections.emptyList());
 
     assertThat(gson.excluder).isEqualTo(CUSTOM_EXCLUDER);
     assertThat(gson.fieldNamingStrategy()).isEqualTo(CUSTOM_FIELD_NAMING_STRATEGY);
@@ -104,7 +96,7 @@ public final class GsonTest {
         new Gson(
             CUSTOM_EXCLUDER,
             CUSTOM_FIELD_NAMING_STRATEGY,
-            new HashMap<Type, InstanceCreator<?>>(),
+            new HashMap<>(),
             true,
             false,
             true,
@@ -117,12 +109,12 @@ public final class GsonTest {
             null,
             DateFormat.DEFAULT,
             DateFormat.DEFAULT,
-            new ArrayList<TypeAdapterFactory>(),
-            new ArrayList<TypeAdapterFactory>(),
-            new ArrayList<TypeAdapterFactory>(),
+            new ArrayList<>(),
+            new ArrayList<>(),
+            new ArrayList<>(),
             CUSTOM_OBJECT_TO_NUMBER_STRATEGY,
             CUSTOM_NUMBER_TO_NUMBER_STRATEGY,
-            Collections.<ReflectionAccessFilter>emptyList());
+            Collections.emptyList());
 
     Gson clone =
         original.newBuilder().registerTypeAdapter(int.class, new TestTypeAdapter()).create();
@@ -142,6 +134,61 @@ public final class GsonTest {
     }
   }
 
+  @Test
+  public void testFromJson_WrongResultType() {
+    class IntegerAdapter extends TypeAdapter<Integer> {
+      @Override
+      public Integer read(JsonReader in) throws IOException {
+        in.skipValue();
+        return 3;
+      }
+
+      @Override
+      public void write(JsonWriter out, Integer value) {
+        throw new AssertionError("not needed for test");
+      }
+
+      @Override
+      public String toString() {
+        return "custom-adapter";
+      }
+    }
+
+    Gson gson = new GsonBuilder().registerTypeAdapter(Boolean.class, new IntegerAdapter()).create();
+    // Use `Class<?>` here to avoid that the JVM itself creates the ClassCastException (though the
+    // check below for the custom message would detect that as well)
+    Class<?> deserializedClass = Boolean.class;
+    var exception =
+        assertThrows(ClassCastException.class, () -> gson.fromJson("true", deserializedClass));
+    assertThat(exception)
+        .hasMessageThat()
+        .isEqualTo(
+            "Type adapter 'custom-adapter' returned wrong type; requested class java.lang.Boolean"
+                + " but got instance of class java.lang.Integer\n"
+                + "Verify that the adapter was registered for the correct type.");
+
+    // Returning boxed primitive should be allowed (e.g. returning `Integer` for `int`)
+    Gson gson2 = new GsonBuilder().registerTypeAdapter(int.class, new IntegerAdapter()).create();
+    assertThat(gson2.fromJson("0", int.class)).isEqualTo(3);
+
+    class NullAdapter extends TypeAdapter<Object> {
+      @Override
+      public Object read(JsonReader in) throws IOException {
+        in.skipValue();
+        return null;
+      }
+
+      @Override
+      public void write(JsonWriter out, Object value) {
+        throw new AssertionError("not needed for test");
+      }
+    }
+
+    // Returning `null` should be allowed
+    Gson gson3 = new GsonBuilder().registerTypeAdapter(Boolean.class, new NullAdapter()).create();
+    assertThat(gson3.fromJson("true", Boolean.class)).isNull();
+  }
+
   @Test
   public void testGetAdapter_Null() {
     Gson gson = new Gson();
@@ -164,9 +211,9 @@ public final class GsonTest {
       }
     }
 
-    final AtomicInteger adapterInstancesCreated = new AtomicInteger(0);
-    final AtomicReference<TypeAdapter<?>> threadAdapter = new AtomicReference<>();
-    final Class<?> requestedType = Number.class;
+    AtomicInteger adapterInstancesCreated = new AtomicInteger(0);
+    AtomicReference<TypeAdapter<?>> threadAdapter = new AtomicReference<>();
+    Class<?> requestedType = Number.class;
 
     Gson gson =
         new GsonBuilder()
@@ -175,7 +222,7 @@ public final class GsonTest {
                   private volatile boolean isFirstCall = true;
 
                   @Override
-                  public <T> TypeAdapter<T> create(final Gson gson, TypeToken<T> type) {
+                  public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
                     if (isFirstCall) {
                       isFirstCall = false;
 
@@ -253,10 +300,10 @@ public final class GsonTest {
       }
     }
 
-    final CountDownLatch isThreadWaiting = new CountDownLatch(1);
-    final CountDownLatch canThreadProceed = new CountDownLatch(1);
+    CountDownLatch isThreadWaiting = new CountDownLatch(1);
+    CountDownLatch canThreadProceed = new CountDownLatch(1);
 
-    final Gson gson =
+    Gson gson =
         new GsonBuilder()
             .registerTypeAdapterFactory(
                 new TypeAdapterFactory() {
@@ -298,7 +345,7 @@ public final class GsonTest {
                 })
             .create();
 
-    final AtomicReference<TypeAdapter<?>> otherThreadAdapter = new AtomicReference<>();
+    AtomicReference<TypeAdapter<?>> otherThreadAdapter = new AtomicReference<>();
     Thread thread =
         new Thread() {
           @Override
@@ -493,23 +540,15 @@ public final class GsonTest {
             out.value("custom-adapter");
           }
         });
+
     gsonBuilder.registerTypeHierarchyAdapter(
         CustomClass2.class,
-        new JsonSerializer<CustomClass2>() {
-          @Override
-          public JsonElement serialize(
-              CustomClass2 src, Type typeOfSrc, JsonSerializationContext context) {
-            return new JsonPrimitive("custom-hierarchy-adapter");
-          }
-        });
+        (JsonSerializer<CustomClass2>)
+            (src, typeOfSrc, context) -> new JsonPrimitive("custom-hierarchy-adapter"));
+
     gsonBuilder.registerTypeAdapter(
         CustomClass3.class,
-        new InstanceCreator<CustomClass3>() {
-          @Override
-          public CustomClass3 createInstance(Type type) {
-            return new CustomClass3("custom-instance");
-          }
-        });
+        (InstanceCreator<CustomClass3>) type -> new CustomClass3("custom-instance"));
 
     assertDefaultGson(gson);
     // New GsonBuilder created from `gson` should not have been affected by changes either
@@ -556,21 +595,11 @@ public final class GsonTest {
                 })
             .registerTypeHierarchyAdapter(
                 CustomClass2.class,
-                new JsonSerializer<CustomClass2>() {
-                  @Override
-                  public JsonElement serialize(
-                      CustomClass2 src, Type typeOfSrc, JsonSerializationContext context) {
-                    return new JsonPrimitive("custom-hierarchy-adapter");
-                  }
-                })
+                (JsonSerializer<CustomClass2>)
+                    (src, typeOfSrc, context) -> new JsonPrimitive("custom-hierarchy-adapter"))
             .registerTypeAdapter(
                 CustomClass3.class,
-                new InstanceCreator<CustomClass3>() {
-                  @Override
-                  public CustomClass3 createInstance(Type type) {
-                    return new CustomClass3("custom-instance");
-                  }
-                })
+                (InstanceCreator<CustomClass3>) type -> new CustomClass3("custom-instance"))
             .create();
 
     assertCustomGson(gson);
@@ -592,21 +621,11 @@ public final class GsonTest {
         });
     gsonBuilder.registerTypeHierarchyAdapter(
         CustomClass2.class,
-        new JsonSerializer<CustomClass2>() {
-          @Override
-          public JsonElement serialize(
-              CustomClass2 src, Type typeOfSrc, JsonSerializationContext context) {
-            return new JsonPrimitive("overwritten custom-hierarchy-adapter");
-          }
-        });
+        (JsonSerializer<CustomClass2>)
+            (src, typeOfSrc, context) -> new JsonPrimitive("overwritten custom-hierarchy-adapter"));
     gsonBuilder.registerTypeAdapter(
         CustomClass3.class,
-        new InstanceCreator<CustomClass3>() {
-          @Override
-          public CustomClass3 createInstance(Type type) {
-            return new CustomClass3("overwritten custom-instance");
-          }
-        });
+        (InstanceCreator<CustomClass3>) type -> new CustomClass3("overwritten custom-instance"));
 
     // `gson` object should not have been affected by changes to new GsonBuilder
     assertCustomGson(gson);
@@ -645,11 +664,12 @@ public final class GsonTest {
 
     final String s;
 
+    @SuppressWarnings("EffectivelyPrivate")
     public CustomClass3(String s) {
       this.s = s;
     }
 
-    @SuppressWarnings("unused") // called by Gson
+    @SuppressWarnings({"unused", "EffectivelyPrivate"}) // called by Gson
     public CustomClass3() {
       this(NO_ARG_CONSTRUCTOR_VALUE);
     }
