@@ -17,7 +17,7 @@
 package com.google.gson.functional;
 
 import static com.google.common.truth.Truth.assertThat;
-import static org.junit.Assert.fail;
+import static org.junit.Assert.assertThrows;
 
 import com.google.common.base.Splitter;
 import com.google.gson.Gson;
@@ -26,7 +26,6 @@ import com.google.gson.InstanceCreator;
 import com.google.gson.JsonDeserializationContext;
 import com.google.gson.JsonDeserializer;
 import com.google.gson.JsonElement;
-import com.google.gson.JsonParseException;
 import com.google.gson.JsonPrimitive;
 import com.google.gson.JsonSerializationContext;
 import com.google.gson.JsonSerializer;
@@ -78,7 +77,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
   @Test
   public void testRegisteredAdapterOverridesJsonAdapter() {
     TypeAdapter<A> typeAdapter =
-        new TypeAdapter<A>() {
+        new TypeAdapter<>() {
           @Override
           public void write(JsonWriter out, A value) throws IOException {
             out.value("registeredAdapter");
@@ -98,12 +97,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
   @Test
   public void testRegisteredSerializerOverridesJsonAdapter() {
     JsonSerializer<A> serializer =
-        new JsonSerializer<A>() {
-          @Override
-          public JsonElement serialize(A src, Type typeOfSrc, JsonSerializationContext context) {
-            return new JsonPrimitive("registeredSerializer");
-          }
-        };
+        (src, typeOfSrc, context) -> new JsonPrimitive("registeredSerializer");
     Gson gson = new GsonBuilder().registerTypeAdapter(A.class, serializer).create();
     String json = gson.toJson(new A("abcd"));
     assertThat(json).isEqualTo("\"registeredSerializer\"");
@@ -114,14 +108,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
   /** The deserializer overrides Json adapter, but for serializer the jsonAdapter is used. */
   @Test
   public void testRegisteredDeserializerOverridesJsonAdapter() {
-    JsonDeserializer<A> deserializer =
-        new JsonDeserializer<A>() {
-          @Override
-          public A deserialize(JsonElement json, Type typeOfT, JsonDeserializationContext context)
-              throws JsonParseException {
-            return new A("registeredDeserializer");
-          }
-        };
+    JsonDeserializer<A> deserializer = (json, typeOfT, context) -> new A("registeredDeserializer");
     Gson gson = new GsonBuilder().registerTypeAdapter(A.class, deserializer).create();
     String json = gson.toJson(new A("abcd"));
     assertThat(json).isEqualTo("\"jsonAdapter\"");
@@ -131,11 +118,9 @@ public final class JsonAdapterAnnotationOnClassesTest {
 
   @Test
   public void testIncorrectTypeAdapterFails() {
-    try {
-      String json = new Gson().toJson(new ClassWithIncorrectJsonAdapter("bar"));
-      fail(json);
-    } catch (ClassCastException expected) {
-    }
+    Gson gson = new Gson();
+    ClassWithIncorrectJsonAdapter obj = new ClassWithIncorrectJsonAdapter("bar");
+    assertThrows(ClassCastException.class, () -> gson.toJson(obj));
   }
 
   @Test
@@ -172,8 +157,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
     assertThat(gson.fromJson("null", WithNullReturningFactory.class)).isNull();
     assertThat(gson.toJson(null, WithNullReturningFactory.class)).isEqualTo("null");
 
-    TypeToken<WithNullReturningFactory<String>> stringTypeArg =
-        new TypeToken<WithNullReturningFactory<String>>() {};
+    TypeToken<WithNullReturningFactory<String>> stringTypeArg = new TypeToken<>() {};
     WithNullReturningFactory<?> deserialized = gson.fromJson("\"a\"", stringTypeArg);
     assertThat(deserialized.t).isEqualTo("custom-read:a");
     assertThat(gson.fromJson("null", stringTypeArg)).isNull();
@@ -183,8 +167,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
 
     // Factory should return `null` for this type and Gson should fall back to reflection-based
     // adapter
-    TypeToken<WithNullReturningFactory<Integer>> numberTypeArg =
-        new TypeToken<WithNullReturningFactory<Integer>>() {};
+    TypeToken<WithNullReturningFactory<Integer>> numberTypeArg = new TypeToken<>() {};
     deserialized = gson.fromJson("{\"t\":1}", numberTypeArg);
     assertThat(deserialized.t).isEqualTo(1);
     assertThat(gson.toJson(new WithNullReturningFactory<>(2), numberTypeArg.getType()))
@@ -197,7 +180,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
   private static class WithNullReturningFactory<T> {
     T t;
 
-    public WithNullReturningFactory(T t) {
+    WithNullReturningFactory(T t) {
       this.t = t;
     }
 
@@ -251,7 +234,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
 
       @Override
       public A read(JsonReader in) throws IOException {
-        in.nextString();
+        String unused = in.nextString();
         return new A("jsonAdapter");
       }
     }
@@ -267,8 +250,8 @@ public final class JsonAdapterAnnotationOnClassesTest {
 
     static final class JsonAdapterFactory implements TypeAdapterFactory {
       @Override
-      public <T> TypeAdapter<T> create(Gson gson, final TypeToken<T> type) {
-        return new TypeAdapter<T>() {
+      public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
+        return new TypeAdapter<>() {
           @Override
           public void write(JsonWriter out, T value) throws IOException {
             out.value("jsonAdapterFactory");
@@ -277,7 +260,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
           @SuppressWarnings("unchecked")
           @Override
           public T read(JsonReader in) throws IOException {
-            in.nextString();
+            String unused = in.nextString();
             return (T) new C("jsonAdapterFactory");
           }
         };
@@ -329,7 +312,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
     public User read(JsonReader in) throws IOException {
       // implement read: split name into firstName and lastName
       in.beginObject();
-      in.nextName();
+      String unused = in.nextName();
       List<String> nameParts = Splitter.on(" ").splitToList(in.nextString());
       in.endObject();
       return new User(nameParts.get(0), nameParts.get(1));
@@ -348,7 +331,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
 
     @Override
     public NullableClass read(JsonReader in) throws IOException {
-      in.nextString();
+      String unused = in.nextString();
       return new NullableClass();
     }
   }
@@ -373,15 +356,20 @@ public final class JsonAdapterAnnotationOnClassesTest {
 
   @Test
   public void testIncorrectJsonAdapterType() {
-    try {
-      new Gson().toJson(new D());
-      fail();
-    } catch (IllegalArgumentException expected) {
-    }
+    Gson gson = new Gson();
+    WithInvalidAdapterClass obj = new WithInvalidAdapterClass();
+    var e = assertThrows(IllegalArgumentException.class, () -> gson.toJson(obj));
+    assertThat(e)
+        .hasMessageThat()
+        .isEqualTo(
+            "Invalid attempt to bind an instance of java.lang.Integer as a @JsonAdapter for "
+                + WithInvalidAdapterClass.class.getName()
+                + ". @JsonAdapter value must be a TypeAdapter, TypeAdapterFactory, JsonSerializer"
+                + " or JsonDeserializer.");
   }
 
   @JsonAdapter(Integer.class)
-  private static final class D {
+  private static final class WithInvalidAdapterClass {
     @SuppressWarnings("unused")
     final String value = "a";
   }
@@ -425,7 +413,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
 
         TypeAdapter<T> delegate = gson.getDelegateAdapter(this, type);
 
-        return new TypeAdapter<T>() {
+        return new TypeAdapter<>() {
           @Override
           public T read(JsonReader in) throws IOException {
             // Perform custom deserialization
@@ -475,7 +463,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
     static class Factory implements TypeAdapterFactory {
       @Override
       public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
-        return new TypeAdapter<T>() {
+        return new TypeAdapter<>() {
           // suppress Error Prone warning; should be clear that `Factory` refers to enclosing class
           @SuppressWarnings("SameNameButDifferent")
           private TypeAdapter<T> delegate() {
@@ -667,7 +655,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
       public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
         TypeAdapter<T> delegate = gson.getDelegateAdapter(this, type);
 
-        return new TypeAdapter<T>() {
+        return new TypeAdapter<>() {
           @Override
           public T read(JsonReader in) throws IOException {
             // Perform custom deserialization
@@ -773,11 +761,11 @@ public final class JsonAdapterAnnotationOnClassesTest {
       private final String value;
 
       @SuppressWarnings("unused")
-      public Serializer() {
+      Serializer() {
         throw new AssertionError("should not be called");
       }
 
-      public Serializer(String value) {
+      Serializer(String value) {
         this.value = value;
       }
 
@@ -804,7 +792,7 @@ public final class JsonAdapterAnnotationOnClassesTest {
 
       // Explicit constructor with args to remove implicit no-args constructor
       @SuppressWarnings("unused")
-      public Serializer(int i) {
+      Serializer(int i) {
         throw new AssertionError("should not be called");
       }
 
