@@ -126,7 +126,7 @@ public final class JsonAdapterAnnotationOnFieldsTest {
   private static final class Part {
     final String name;
 
-    public Part(String name) {
+    Part(String name) {
       this.name = name;
     }
   }
@@ -146,8 +146,8 @@ public final class JsonAdapterAnnotationOnFieldsTest {
 
   private static class GizmoPartTypeAdapterFactory implements TypeAdapterFactory {
     @Override
-    public <T> TypeAdapter<T> create(Gson gson, final TypeToken<T> type) {
-      return new TypeAdapter<T>() {
+    public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
+      return new TypeAdapter<>() {
         @Override
         public void write(JsonWriter out, T value) throws IOException {
           out.value("GizmoPartTypeAdapterFactory");
@@ -173,7 +173,7 @@ public final class JsonAdapterAnnotationOnFieldsTest {
 
   @JsonAdapter(UserClassAnnotationAdapter.class)
   private static class User {
-    public final String name;
+    final String name;
 
     private User(String name) {
       this.name = name;
@@ -303,7 +303,7 @@ public final class JsonAdapterAnnotationOnFieldsTest {
 
   private static final class LongToStringTypeAdapterFactory implements TypeAdapterFactory {
     static final TypeAdapter<Long> ADAPTER =
-        new TypeAdapter<Long>() {
+        new TypeAdapter<>() {
           @Override
           public void write(JsonWriter out, Long value) throws IOException {
             out.value(value.toString());
@@ -317,7 +317,7 @@ public final class JsonAdapterAnnotationOnFieldsTest {
 
     @SuppressWarnings("unchecked")
     @Override
-    public <T> TypeAdapter<T> create(Gson gson, final TypeToken<T> type) {
+    public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
       Class<?> cls = type.getRawType();
       if (Long.class.isAssignableFrom(cls)) {
         return (TypeAdapter<T>) ADAPTER;
@@ -351,8 +351,8 @@ public final class JsonAdapterAnnotationOnFieldsTest {
 
   private static class Gizmo2PartTypeAdapterFactory implements TypeAdapterFactory {
     @Override
-    public <T> TypeAdapter<T> create(Gson gson, final TypeToken<T> type) {
-      return new TypeAdapter<T>() {
+    public <T> TypeAdapter<T> create(Gson gson, TypeToken<T> type) {
+      return new TypeAdapter<>() {
         @Override
         public void write(JsonWriter out, T value) throws IOException {
           out.value("GizmoPartTypeAdapterFactory");
