@@ -17,27 +17,32 @@
 package com.google.gson.functional;
 
 import static com.google.common.truth.Truth.assertThat;
-import static org.junit.Assert.fail;
+import static com.google.common.truth.Truth.assertWithMessage;
+import static org.junit.Assert.assertThrows;
 
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
 import com.google.gson.InstanceCreator;
 import com.google.gson.JsonArray;
 import com.google.gson.JsonElement;
+import com.google.gson.JsonIOException;
 import com.google.gson.JsonParseException;
 import com.google.gson.JsonParser;
 import com.google.gson.JsonPrimitive;
-import com.google.gson.JsonSerializationContext;
 import com.google.gson.JsonSerializer;
 import com.google.gson.JsonSyntaxException;
 import com.google.gson.common.TestTypes;
-import com.google.gson.internal.$Gson$Types;
+import com.google.gson.internal.GsonTypes;
+import com.google.gson.internal.LinkedTreeMap;
 import com.google.gson.reflect.TypeToken;
 import java.lang.reflect.Type;
+import java.util.AbstractMap;
 import java.util.Collection;
+import java.util.Collections;
 import java.util.HashMap;
 import java.util.LinkedHashMap;
 import java.util.Map;
+import java.util.Set;
 import java.util.SortedMap;
 import java.util.TreeMap;
 import java.util.concurrent.ConcurrentHashMap;
@@ -210,6 +215,48 @@ public class MapTest {
     assertThat(map.get(longKey)).isEqualTo("456");
   }
 
+  @Test
+  public void testMapStringKeyDeserialization() {
+    Type typeOfMap = new TypeToken<Map<String, Integer>>() {}.getType();
+    Map<?, ?> map = gson.fromJson("{\"a\":1}", typeOfMap);
+
+    assertWithMessage(
+            "Map<String, ...> should use LinkedTreeMap to protect against DoS in older JDK"
+                + " versions")
+        .that(map)
+        .isInstanceOf(LinkedTreeMap.class);
+
+    Map<?, ?> expectedMap = Collections.singletonMap("a", 1);
+    assertThat(map).isEqualTo(expectedMap);
+  }
+
+  @Test
+  public void testMapStringSupertypeKeyDeserialization() {
+    // Should only use Gson's LinkedTreeMap for String as key, but not for supertypes (e.g. Object)
+    Type typeOfMap = new TypeToken<Map<Object, Integer>>() {}.getType();
+    Map<?, ?> map = gson.fromJson("{\"a\":1}", typeOfMap);
+
+    assertWithMessage("Map<Object, ...> should not use Gson Map implementation")
+        .that(map)
+        .isNotInstanceOf(LinkedTreeMap.class);
+
+    Map<?, ?> expectedMap = Collections.singletonMap("a", 1);
+    assertThat(map).isEqualTo(expectedMap);
+  }
+
+  @Test
+  public void testMapNonStringKeyDeserialization() {
+    Type typeOfMap = new TypeToken<Map<Integer, Integer>>() {}.getType();
+    Map<?, ?> map = gson.fromJson("{\"1\":1}", typeOfMap);
+
+    assertWithMessage("Map<Integer, ...> should not use Gson Map implementation")
+        .that(map)
+        .isNotInstanceOf(LinkedTreeMap.class);
+
+    Map<?, ?> expectedMap = Collections.singletonMap(1, 1);
+    assertThat(map).isEqualTo(expectedMap);
+  }
+
   @Test
   public void testHashMapDeserialization() {
     Type typeOfMap = new TypeToken<HashMap<Integer, String>>() {}.getType();
@@ -311,14 +358,7 @@ public class MapTest {
   public void testMapSubclassDeserialization() {
     Gson gson =
         new GsonBuilder()
-            .registerTypeAdapter(
-                MyMap.class,
-                new InstanceCreator<MyMap>() {
-                  @Override
-                  public MyMap createInstance(Type type) {
-                    return new MyMap();
-                  }
-                })
+            .registerTypeAdapter(MyMap.class, (InstanceCreator<MyMap>) type -> new MyMap())
             .create();
     String json = "{\"a\":1,\"b\":2}";
     MyMap map = gson.fromJson(json, MyMap.class);
@@ -328,23 +368,19 @@ public class MapTest {
 
   @Test
   public void testCustomSerializerForSpecificMapType() {
-    Type type =
-        $Gson$Types.newParameterizedTypeWithOwner(null, Map.class, String.class, Long.class);
+    Type type = GsonTypes.newParameterizedTypeWithOwner(null, Map.class, String.class, Long.class);
     Gson gson =
         new GsonBuilder()
             .registerTypeAdapter(
                 type,
-                new JsonSerializer<Map<String, Long>>() {
-                  @Override
-                  public JsonElement serialize(
-                      Map<String, Long> src, Type typeOfSrc, JsonSerializationContext context) {
-                    JsonArray array = new JsonArray();
-                    for (long value : src.values()) {
-                      array.add(new JsonPrimitive(value));
-                    }
-                    return array;
-                  }
-                })
+                (JsonSerializer<Map<String, Long>>)
+                    (src, typeOfSrc, context) -> {
+                      JsonArray array = new JsonArray();
+                      for (long value : src.values()) {
+                        array.add(new JsonPrimitive(value));
+                      }
+                      return array;
+                    })
             .create();
 
     Map<String, Long> src = new LinkedHashMap<>();
@@ -355,6 +391,51 @@ public class MapTest {
     assertThat(gson.toJson(src, type)).isEqualTo("[1,2,3]");
   }
 
+  private static class MapWithoutNoArgsConstructor<K, V> extends AbstractMap<K, V> {
+    // Remove implicit no-args constructor
+    MapWithoutNoArgsConstructor(int unused) {}
+
+    @Override
+    public V put(K key, V value) {
+      throw new AssertionError("not used by test");
+    }
+
+    @Override
+    public Set<Entry<K, V>> entrySet() {
+      return Collections.emptySet();
+    }
+  }
+
+  /**
+   * Tests that when a custom Map class without no-args constructor is deserialized, Gson does not
+   * use JDK Unsafe to create an instance, since that likely leads to a broken Map instance.
+   */
+  @Test
+  public void testMapWithoutNoArgsConstructor() {
+    var mapType = new TypeToken<MapWithoutNoArgsConstructor<String, String>>() {};
+    JsonIOException e = assertThrows(JsonIOException.class, () -> gson.fromJson("{}", mapType));
+    assertThat(e)
+        .hasMessageThat()
+        .isEqualTo(
+            "Unable to create instance of "
+                + MapWithoutNoArgsConstructor.class
+                + "; Register an InstanceCreator or a TypeAdapter for this type.");
+
+    // But serialization should work fine
+    assertThat(gson.toJson(new MapWithoutNoArgsConstructor<>(0))).isEqualTo("{}");
+
+    // Deserialization should work when registering custom creator
+    gson =
+        new GsonBuilder()
+            .registerTypeAdapter(
+                MapWithoutNoArgsConstructor.class,
+                (InstanceCreator<MapWithoutNoArgsConstructor<?, ?>>)
+                    type -> new MapWithoutNoArgsConstructor<>(0))
+            .create();
+    var map = gson.fromJson("{}", mapType);
+    assertThat(map).isInstanceOf(MapWithoutNoArgsConstructor.class);
+  }
+
   /** Created in response to http://code.google.com/p/google-gson/issues/detail?id=99 */
   private static class ClassWithAMap {
     Map<String, String> map = new TreeMap<>();
@@ -455,7 +536,7 @@ public class MapTest {
   public void testReadMapsWithEmptyStringKey() {
     Map<String, Boolean> map =
         gson.fromJson("{\"\":true}", new TypeToken<Map<String, Boolean>>() {}.getType());
-    assertThat(map.get("")).isEqualTo(Boolean.TRUE);
+    assertThat(map.get("")).isEqualTo(true);
   }
 
   /** From bug report http://code.google.com/p/google-gson/issues/detail?id=204 */
@@ -520,19 +601,13 @@ public class MapTest {
 
     Gson tempGson = new Gson();
     String subTypeJson = tempGson.toJson(subType);
-    final JsonElement baseTypeJsonElement = tempGson.toJsonTree(subType, TestTypes.Base.class);
+    JsonElement baseTypeJsonElement = tempGson.toJsonTree(subType, TestTypes.Base.class);
     String baseTypeJson = tempGson.toJson(baseTypeJsonElement);
     String expected =
         "{\"bases\":{\"Test\":" + baseTypeJson + "},\"subs\":{\"Test\":" + subTypeJson + "}}";
 
     JsonSerializer<TestTypes.Base> baseTypeAdapter =
-        new JsonSerializer<TestTypes.Base>() {
-          @Override
-          public JsonElement serialize(
-              TestTypes.Base src, Type typeOfSrc, JsonSerializationContext context) {
-            return baseTypeJsonElement;
-          }
-        };
+        (src, typeOfSrc, context) -> baseTypeJsonElement;
 
     Gson gson =
         new GsonBuilder()
@@ -576,11 +651,12 @@ public class MapTest {
   @Test
   public void testComplexKeysDeserialization() {
     String json = "{'2,3':'a','5,7':'b'}";
-    try {
-      gson.fromJson(json, new TypeToken<Map<Point, String>>() {}.getType());
-      fail();
-    } catch (JsonParseException expected) {
-    }
+    Type type = new TypeToken<Map<Point, String>>() {}.getType();
+    var e = assertThrows(JsonParseException.class, () -> gson.fromJson(json, type));
+    assertThat(e)
+        .hasCauseThat()
+        .hasMessageThat()
+        .startsWith("Expected BEGIN_OBJECT but was STRING at line 1 column 3 path $.\n");
   }
 
   @Test
@@ -612,11 +688,9 @@ public class MapTest {
 
   @Test
   public void testMapDeserializationWithDuplicateKeys() {
-    try {
-      gson.fromJson("{'a':1,'a':2}", new TypeToken<Map<String, Integer>>() {}.getType());
-      fail();
-    } catch (JsonSyntaxException expected) {
-    }
+    Type type = new TypeToken<Map<String, Integer>>() {}.getType();
+    var e = assertThrows(JsonSyntaxException.class, () -> gson.fromJson("{'a':1,'a':2}", type));
+    assertThat(e).hasMessageThat().isEqualTo("duplicate key: a");
   }
 
   @Test
