@@ -17,22 +17,20 @@
 package com.google.gson.functional;
 
 import static com.google.common.truth.Truth.assertThat;
-import static org.junit.Assert.fail;
+import static org.junit.Assert.assertThrows;
 
 import com.google.gson.ExclusionStrategy;
 import com.google.gson.FieldAttributes;
 import com.google.gson.Gson;
 import com.google.gson.GsonBuilder;
 import com.google.gson.InstanceCreator;
-import com.google.gson.JsonDeserializationContext;
 import com.google.gson.JsonDeserializer;
-import com.google.gson.JsonElement;
 import com.google.gson.JsonIOException;
 import com.google.gson.JsonObject;
 import com.google.gson.JsonParseException;
 import com.google.gson.JsonPrimitive;
-import com.google.gson.JsonSerializationContext;
 import com.google.gson.JsonSerializer;
+import com.google.gson.JsonSyntaxException;
 import com.google.gson.common.TestTypes.ArrayOfObjects;
 import com.google.gson.common.TestTypes.BagOfPrimitiveWrappers;
 import com.google.gson.common.TestTypes.BagOfPrimitives;
@@ -43,6 +41,8 @@ import com.google.gson.common.TestTypes.ClassWithTransientFields;
 import com.google.gson.common.TestTypes.Nested;
 import com.google.gson.common.TestTypes.PrimitiveArray;
 import com.google.gson.reflect.TypeToken;
+import com.google.gson.stream.MalformedJsonException;
+import java.io.EOFException;
 import java.lang.reflect.Type;
 import java.util.ArrayList;
 import java.util.Collection;
@@ -183,12 +183,8 @@ public class ObjectTest {
             + " com.google.gson.functional.ObjectTest$Superclass2#s\n"
             + "See https://github.com/google/gson/blob/main/Troubleshooting.md#duplicate-fields";
 
-    try {
-      gson.getAdapter(Subclass.class);
-      fail();
-    } catch (IllegalArgumentException e) {
-      assertThat(e).hasMessageThat().isEqualTo(expectedMessage);
-    }
+    var e = assertThrows(IllegalArgumentException.class, () -> gson.getAdapter(Subclass.class));
+    assertThat(e).hasMessageThat().isEqualTo(expectedMessage);
 
     // Detection should also work properly when duplicate fields exist only for serialization
     Gson gson =
@@ -208,12 +204,8 @@ public class ObjectTest {
                 })
             .create();
 
-    try {
-      gson.getAdapter(Subclass.class);
-      fail();
-    } catch (IllegalArgumentException e) {
-      assertThat(e).hasMessageThat().isEqualTo(expectedMessage);
-    }
+    e = assertThrows(IllegalArgumentException.class, () -> gson.getAdapter(Subclass.class));
+    assertThat(e).hasMessageThat().isEqualTo(expectedMessage);
   }
 
   @Test
@@ -248,11 +240,9 @@ public class ObjectTest {
 
   @Test
   public void testTruncatedDeserialization() {
-    try {
-      gson.fromJson("[\"a\", \"b\",", new TypeToken<List<String>>() {}.getType());
-      fail();
-    } catch (JsonParseException expected) {
-    }
+    Type type = new TypeToken<List<String>>() {}.getType();
+    var e = assertThrows(JsonParseException.class, () -> gson.fromJson("[\"a\", \"b\",", type));
+    assertThat(e).hasCauseThat().isInstanceOf(EOFException.class);
   }
 
   @Test
@@ -395,13 +385,8 @@ public class ObjectTest {
         new GsonBuilder()
             .registerTypeHierarchyAdapter(
                 ClassWithNoFields.class,
-                new JsonSerializer<ClassWithNoFields>() {
-                  @Override
-                  public JsonElement serialize(
-                      ClassWithNoFields src, Type typeOfSrc, JsonSerializationContext context) {
-                    return new JsonPrimitive("custom-value");
-                  }
-                })
+                (JsonSerializer<ClassWithNoFields>)
+                    (src, typeOfSrc, context) -> new JsonPrimitive("custom-value"))
             .create();
 
     assertThat(
@@ -416,13 +401,8 @@ public class ObjectTest {
         new GsonBuilder()
             .registerTypeAdapter(
                 Local.class,
-                new JsonSerializer<Local>() {
-                  @Override
-                  public JsonElement serialize(
-                      Local src, Type typeOfSrc, JsonSerializationContext context) {
-                    return new JsonPrimitive("custom-value");
-                  }
-                })
+                (JsonSerializer<Local>)
+                    (src, typeOfSrc, context) -> new JsonPrimitive("custom-value"))
             .create();
     assertThat(gson.toJson(new Local())).isEqualTo("\"custom-value\"");
   }
@@ -433,13 +413,8 @@ public class ObjectTest {
         new GsonBuilder()
             .registerTypeHierarchyAdapter(
                 ClassWithNoFields.class,
-                new JsonDeserializer<ClassWithNoFields>() {
-                  @Override
-                  public ClassWithNoFields deserialize(
-                      JsonElement json, Type typeOfT, JsonDeserializationContext context) {
-                    return new ClassWithNoFields();
-                  }
-                })
+                (JsonDeserializer<ClassWithNoFields>)
+                    (json, typeOfT, context) -> new ClassWithNoFields())
             .create();
 
     assertThat(gson.fromJson("{}", ClassWithNoFields.class)).isNotNull();
@@ -452,13 +427,10 @@ public class ObjectTest {
         new GsonBuilder()
             .registerTypeAdapter(
                 Local.class,
-                new JsonDeserializer<Local>() {
-                  @Override
-                  public Local deserialize(
-                      JsonElement json, Type typeOfT, JsonDeserializationContext context) {
-                    throw new AssertionError("should not be called");
-                  }
-                })
+                (JsonDeserializer<Local>)
+                    (json, typeOfT, context) -> {
+                      throw new AssertionError("should not be called");
+                    })
             .create();
     // Custom deserializer is ignored
     assertThat(gson.fromJson("{}", Local.class)).isNull();
@@ -495,7 +467,7 @@ public class ObjectTest {
 
   @Test
   public void testInnerClassDeserialization() {
-    final Parent p = new Parent();
+    Parent p = new Parent();
     Gson gson =
         new GsonBuilder()
             .registerTypeAdapter(
@@ -525,7 +497,7 @@ public class ObjectTest {
   private static class ArrayOfArrays {
     private final BagOfPrimitives[][] elements;
 
-    public ArrayOfArrays() {
+    ArrayOfArrays() {
       elements = new BagOfPrimitives[3][2];
       for (int i = 0; i < elements.length; ++i) {
         BagOfPrimitives[] row = elements[i];
@@ -535,7 +507,7 @@ public class ObjectTest {
       }
     }
 
-    public String getExpectedJson() {
+    String getExpectedJson() {
       StringBuilder sb = new StringBuilder("{\"elements\":[");
       boolean first = true;
       for (BagOfPrimitives[] row : elements) {
@@ -562,7 +534,7 @@ public class ObjectTest {
   }
 
   private static class ClassWithPrivateNoArgsConstructor {
-    public int a;
+    int a;
 
     private ClassWithPrivateNoArgsConstructor() {
       a = 10;
@@ -635,18 +607,24 @@ public class ObjectTest {
     Gson gson = new Gson();
     Product product = new Product();
     assertThat(gson.toJson(product)).isEqualTo("{\"attributes\":[],\"departments\":[]}");
-    Product unused1 = gson.fromJson(gson.toJson(product), Product.class);
+    Product deserialized = gson.fromJson(gson.toJson(product), Product.class);
+    assertThat(deserialized.attributes).isEmpty();
+    assertThat(deserialized.departments).isEmpty();
 
     product.departments.add(new Department());
     assertThat(gson.toJson(product))
         .isEqualTo("{\"attributes\":[],\"departments\":[{\"name\":\"abc\",\"code\":\"123\"}]}");
-    Product unused2 = gson.fromJson(gson.toJson(product), Product.class);
+    deserialized = gson.fromJson(gson.toJson(product), Product.class);
+    assertThat(deserialized.attributes).isEmpty();
+    assertThat(deserialized.departments).hasSize(1);
 
     product.attributes.add("456");
     assertThat(gson.toJson(product))
         .isEqualTo(
             "{\"attributes\":[\"456\"],\"departments\":[{\"name\":\"abc\",\"code\":\"123\"}]}");
-    Product unused3 = gson.fromJson(gson.toJson(product), Product.class);
+    deserialized = gson.fromJson(gson.toJson(product), Product.class);
+    assertThat(deserialized.attributes).containsExactly("456");
+    assertThat(deserialized.departments).hasSize(1);
   }
 
   static final class Department {
@@ -706,7 +684,9 @@ public class ObjectTest {
   @Test
   public void testStaticFieldDeserialization() {
     // By default Gson should ignore static fields
-    ClassWithStaticField unused = gson.fromJson("{\"s\":\"custom\"}", ClassWithStaticField.class);
+    ClassWithStaticField deserialized =
+        gson.fromJson("{\"s\":\"custom\"}", ClassWithStaticField.class);
+    assertThat(deserialized).isNotNull();
     assertThat(ClassWithStaticField.s).isEqualTo("initial");
 
     Gson gson =
@@ -724,16 +704,15 @@ public class ObjectTest {
       ClassWithStaticField.s = oldValue;
     }
 
-    try {
-      gson.fromJson("{\"s\":\"custom\"}", ClassWithStaticFinalField.class);
-      fail();
-    } catch (JsonIOException e) {
-      assertThat(e)
-          .hasMessageThat()
-          .isEqualTo(
-              "Cannot set value of 'static final' field"
-                  + " 'com.google.gson.functional.ObjectTest$ClassWithStaticFinalField#s'");
-    }
+    var e =
+        assertThrows(
+            JsonIOException.class,
+            () -> gson.fromJson("{\"s\":\"custom\"}", ClassWithStaticFinalField.class));
+    assertThat(e)
+        .hasMessageThat()
+        .isEqualTo(
+            "Cannot set value of 'static final' field"
+                + " 'com.google.gson.functional.ObjectTest$ClassWithStaticFinalField#s'");
   }
 
   @SuppressWarnings({"PrivateConstructorForUtilityClass", "NonFinalStaticField"})
@@ -748,28 +727,50 @@ public class ObjectTest {
 
   @Test
   public void testThrowingDefaultConstructor() {
-    try {
-      gson.fromJson("{}", ClassWithThrowingConstructor.class);
-      fail();
-    }
     // TODO: Adjust this once Gson throws more specific exception type
-    catch (RuntimeException e) {
-      assertThat(e)
-          .hasMessageThat()
-          .isEqualTo(
-              "Failed to invoke constructor"
-                  + " 'com.google.gson.functional.ObjectTest$ClassWithThrowingConstructor()' with"
-                  + " no args");
-      assertThat(e).hasCauseThat().isSameInstanceAs(ClassWithThrowingConstructor.thrownException);
-    }
+    var e =
+        assertThrows(
+            RuntimeException.class, () -> gson.fromJson("{}", ClassWithThrowingConstructor.class));
+    assertThat(e)
+        .hasMessageThat()
+        .isEqualTo(
+            "Failed to invoke constructor"
+                + " 'com.google.gson.functional.ObjectTest$ClassWithThrowingConstructor()' with"
+                + " no args");
+    assertThat(e).hasCauseThat().isSameInstanceAs(ClassWithThrowingConstructor.thrownException);
   }
 
-  @SuppressWarnings("StaticAssignmentOfThrowable")
   static class ClassWithThrowingConstructor {
+    @SuppressWarnings("StaticAssignmentOfThrowable")
     static final RuntimeException thrownException = new RuntimeException("Custom exception");
 
     public ClassWithThrowingConstructor() {
       throw thrownException;
     }
   }
+
+  @Test
+  public void testDeeplyNested() {
+    int defaultLimit = 255;
+    // json = {"r":{"r": ... {"r":null} ... }}
+    String json = "{\"r\":".repeat(defaultLimit) + "null" + "}".repeat(defaultLimit);
+    RecursiveClass deserialized = gson.fromJson(json, RecursiveClass.class);
+    assertThat(deserialized).isNotNull();
+    assertThat(deserialized.r).isNotNull();
+
+    // json = {"r":{"r": ... {"r":null} ... }}
+    String json2 = "{\"r\":".repeat(defaultLimit + 1) + "null" + "}".repeat(defaultLimit + 1);
+    JsonSyntaxException e =
+        assertThrows(JsonSyntaxException.class, () -> gson.fromJson(json2, RecursiveClass.class));
+    assertThat(e).hasCauseThat().isInstanceOf(MalformedJsonException.class);
+    assertThat(e)
+        .hasCauseThat()
+        .hasMessageThat()
+        .isEqualTo(
+            "Nesting limit 255 reached at line 1 column 1277 path $" + ".r".repeat(defaultLimit));
+  }
+
+  private static class RecursiveClass {
+    RecursiveClass r;
+  }
 }
