@@ -120,11 +120,11 @@ public class ParameterizedTypesTest {
             .create();
     MyParameterizedType<Integer> intTarget = new MyParameterizedType<>(10);
     String json = gson.toJson(intTarget, ptIntegerType);
-    assertThat(json).isEqualTo(MyParameterizedTypeAdapter.<Integer>getExpectedJson(intTarget));
+    assertThat(json).isEqualTo(MyParameterizedTypeAdapter.getExpectedJson(intTarget));
 
     MyParameterizedType<String> stringTarget = new MyParameterizedType<>("abc");
     json = gson.toJson(stringTarget, ptStringType);
-    assertThat(json).isEqualTo(MyParameterizedTypeAdapter.<String>getExpectedJson(stringTarget));
+    assertThat(json).isEqualTo(MyParameterizedTypeAdapter.getExpectedJson(stringTarget));
   }
 
   @Test
@@ -140,12 +140,12 @@ public class ParameterizedTypesTest {
             .create();
 
     MyParameterizedType<Integer> src = new MyParameterizedType<>(10);
-    String json = MyParameterizedTypeAdapter.<Integer>getExpectedJson(src);
+    String json = MyParameterizedTypeAdapter.getExpectedJson(src);
     MyParameterizedType<Integer> intTarget = gson.fromJson(json, ptIntegerType);
     assertThat(intTarget.value).isEqualTo(10);
 
     MyParameterizedType<String> srcStr = new MyParameterizedType<>("abc");
-    json = MyParameterizedTypeAdapter.<String>getExpectedJson(srcStr);
+    json = MyParameterizedTypeAdapter.getExpectedJson(srcStr);
     MyParameterizedType<String> stringTarget = gson.fromJson(json, ptStringType);
     assertThat(stringTarget.value).isEqualTo("abc");
   }
@@ -305,7 +305,7 @@ public class ParameterizedTypesTest {
       this(null, null, null, null, null, null);
     }
 
-    public ObjectWithTypeVariables(
+    ObjectWithTypeVariables(
         T obj,
         T[] array,
         List<T> list,
@@ -320,7 +320,7 @@ public class ParameterizedTypesTest {
       this.arrayOfListOfWildcardTypeParameters = arrayOfWildcardList;
     }
 
-    public String getExpectedJson() {
+    String getExpectedJson() {
       StringBuilder sb = new StringBuilder().append("{");
 
       boolean needsComma = false;
@@ -410,7 +410,7 @@ public class ParameterizedTypesTest {
       }
     }
 
-    public String toString(T obj) {
+    String toString(T obj) {
       return obj.toString();
     }
   }
@@ -437,7 +437,7 @@ public class ParameterizedTypesTest {
 
     @Override
     public int hashCode() {
-      final int prime = 31;
+      int prime = 31;
       int result = 1;
       result = prime * result + ((a == null) ? 0 : a.hashCode());
       result = prime * result + ((b == null) ? 0 : b.hashCode());
@@ -515,7 +515,7 @@ public class ParameterizedTypesTest {
 
   @Test
   public void testGsonFromJsonTypeToken() {
-    TypeToken<List<Quantity>> typeToken = new TypeToken<List<Quantity>>() {};
+    TypeToken<List<Quantity>> typeToken = new TypeToken<>() {};
     Type type = typeToken.getType();
 
     {
