@@ -17,7 +17,7 @@
 package com.google.gson.internal;
 
 import static com.google.common.truth.Truth.assertThat;
-import static org.junit.Assert.fail;
+import static org.junit.Assert.assertThrows;
 
 import com.google.gson.common.MoreAsserts;
 import java.io.ByteArrayInputStream;
@@ -25,8 +25,6 @@ import java.io.ByteArrayOutputStream;
 import java.io.IOException;
 import java.io.ObjectInputStream;
 import java.io.ObjectOutputStream;
-import java.util.ArrayList;
-import java.util.Arrays;
 import java.util.Collections;
 import java.util.Iterator;
 import java.util.Map;
@@ -42,8 +40,8 @@ public final class LinkedTreeMapTest {
     map.put("a", "android");
     map.put("c", "cola");
     map.put("b", "bbq");
-    assertIterationOrder(map.keySet(), "a", "c", "b");
-    assertIterationOrder(map.values(), "android", "cola", "bbq");
+    assertThat(map.keySet()).containsExactly("a", "c", "b").inOrder();
+    assertThat(map.values()).containsExactly("android", "cola", "bbq").inOrder();
   }
 
   @Test
@@ -57,29 +55,22 @@ public final class LinkedTreeMapTest {
     it.next();
     it.next();
     it.remove();
-    assertIterationOrder(map.keySet(), "a", "c");
+    assertThat(map.keySet()).containsExactly("a", "c").inOrder();
   }
 
   @Test
   @SuppressWarnings("ModifiedButNotUsed")
   public void testPutNullKeyFails() {
     LinkedTreeMap<String, String> map = new LinkedTreeMap<>();
-    try {
-      map.put(null, "android");
-      fail();
-    } catch (NullPointerException expected) {
-    }
+    var e = assertThrows(NullPointerException.class, () -> map.put(null, "android"));
+    assertThat(e).hasMessageThat().isEqualTo("key == null");
   }
 
   @Test
   @SuppressWarnings("ModifiedButNotUsed")
   public void testPutNonComparableKeyFails() {
     LinkedTreeMap<Object, String> map = new LinkedTreeMap<>();
-    try {
-      map.put(new Object(), "android");
-      fail();
-    } catch (ClassCastException expected) {
-    }
+    assertThrows(ClassCastException.class, () -> map.put(new Object(), "android"));
   }
 
   @Test
@@ -96,12 +87,9 @@ public final class LinkedTreeMapTest {
   @Test
   public void testPutNullValue_Forbidden() {
     LinkedTreeMap<String, String> map = new LinkedTreeMap<>(false);
-    try {
-      map.put("a", null);
-      fail();
-    } catch (NullPointerException e) {
-      assertThat(e).hasMessageThat().isEqualTo("value == null");
-    }
+    var e = assertThrows(NullPointerException.class, () -> map.put("a", null));
+    assertThat(e).hasMessageThat().isEqualTo("value == null");
+
     assertThat(map).hasSize(0);
     assertThat(map).doesNotContainKey("a");
     assertThat(map.containsValue(null)).isFalse();
@@ -128,12 +116,9 @@ public final class LinkedTreeMapTest {
     LinkedTreeMap<String, String> map = new LinkedTreeMap<>(false);
     map.put("a", "1");
     Entry<String, String> entry = map.entrySet().iterator().next();
-    try {
-      entry.setValue(null);
-      fail();
-    } catch (NullPointerException e) {
-      assertThat(e).hasMessageThat().isEqualTo("value == null");
-    }
+    var e = assertThrows(NullPointerException.class, () -> entry.setValue(null));
+    assertThat(e).hasMessageThat().isEqualTo("value == null");
+
     assertThat(entry.getValue()).isEqualTo("1");
     assertThat(map.get("a")).isEqualTo("1");
     assertThat(map.containsValue(null)).isFalse();
@@ -199,8 +184,8 @@ public final class LinkedTreeMapTest {
     map.put("c", "cola");
     map.put("b", "bbq");
     map.clear();
-    assertIterationOrder(map.keySet());
-    assertThat(map).hasSize(0);
+    assertThat(map.keySet()).isEmpty();
+    assertThat(map).isEmpty();
   }
 
   @Test
@@ -234,14 +219,4 @@ public final class LinkedTreeMapTest {
     Map<String, Integer> deserialized = (Map<String, Integer>) objIn.readObject();
     assertThat(deserialized).isEqualTo(Collections.singletonMap("a", 1));
   }
-
-  @SuppressWarnings("varargs")
-  @SafeVarargs
-  private static final <T> void assertIterationOrder(Iterable<T> actual, T... expected) {
-    ArrayList<T> actualList = new ArrayList<>();
-    for (T t : actual) {
-      actualList.add(t);
-    }
-    assertThat(actualList).isEqualTo(Arrays.asList(expected));
-  }
 }
