@@ -95,7 +95,7 @@ public final class TypeTokenTest {
         .isEqualTo(
             "Unsupported type, expected one of: java.lang.Class,"
                 + " java.lang.reflect.ParameterizedType, java.lang.reflect.GenericArrayType, but"
-                + " got: com.google.gson.internal.$Gson$Types$WildcardTypeImpl, for type token: "
+                + " got: com.google.gson.internal.GsonTypes$WildcardTypeImpl, for type token: "
                 + wildcardTypeToken);
   }
 
@@ -282,6 +282,7 @@ public final class TypeTokenTest {
                 + GenericWithMultiBound.class);
 
     class Outer {
+      @SuppressWarnings("ClassCanBeStatic")
       class NonStaticInner<T> {}
     }
 
@@ -328,7 +329,7 @@ public final class TypeTokenTest {
   }
 
   private static <M> void createTypeTokenTypeVariable() {
-    new TypeToken<M>() {};
+    var unused = new TypeToken<M>() {};
   }
 
   /**
@@ -344,6 +345,7 @@ public final class TypeTokenTest {
   public void testTypeTokenTypeVariable() throws Exception {
     // Put the test code inside generic class to be able to access `T`
     class Enclosing<T> {
+      @SuppressWarnings("ClassCanBeStatic")
       class Inner {}
 
       void test() {
