@@ -63,7 +63,7 @@ public class BagOfPrimitives {
 
   @Override
   public int hashCode() {
-    final int prime = 31;
+    int prime = 31;
     int result = 1;
     result = prime * result + (booleanValue ? 1231 : 1237);
     result = prime * result + intValue;
